Take a list of calls, return a string Each element of the list will be converted to a string, and then combined with the other elements
calls_to_string(list_of_calls, sep = " + \n")a list of calls
a character string to separate the items of `list_of_calls` when they are converted to a single string
A length-one character vector; each element of `list_of_calls` will be converted to a string; each string will be combined, separated by `sep`